Module: Scripref::Bookorder
- Defined in:
- lib/scripref/bookorder.rb
Overview
Module to handle differend orderings of bible books using standardized IDs (see https://wiki.crosswire.org/OSIS_Book_Abbreviations)
Module to handle differend orderings of bible books using standardized IDs (see https://wiki.crosswire.org/OSIS_Book_Abbreviations)